@@ -1,9 +1,9 @@
-from shortcuts.actions.base import BaseAction, Field, DictionaryField
+from shortcuts.actions.base import BaseAction, DictionaryField, Field
 
 
 class GetDictionaryValueAction(BaseAction):
     '''Get dictionary value'''
-    type = 'is.workflow.actions.getvalueforkey'
+    itype = 'is.workflow.actions.getvalueforkey'
     keyword = 'get_value_for_key'
 
     key = Field('WFDictionaryKey')
@@ -11,7 +11,7 @@ class GetDictionaryValueAction(BaseAction):
 
 class DictionaryAction(BaseAction):
     '''Dictionary'''
-    type = 'is.workflow.actions.dictionary'
+    itype = 'is.workflow.actions.dictionary'
     keyword = 'dictionary'
 
     items = DictionaryField('WFItems')
