@@ -1,9 +1,9 @@
-from shortcuts.actions.base import BaseAction, VariablesField, Field
+from shortcuts.actions.base import BaseAction, Field, VariablesField
 
 
 class CommentAction(BaseAction):
     '''Comment: just a comment'''
-    type = 'is.workflow.actions.comment'
+    itype = 'is.workflow.actions.comment'
     keyword = 'comment'
 
     text = Field('WFCommentActionText', help='Text to show in the comment')
@@ -11,7 +11,7 @@ class CommentAction(BaseAction):
 
 class TextAction(BaseAction):
     '''Text: returns text as an output'''
-    type = 'is.workflow.actions.gettext'
+    itype = 'is.workflow.actions.gettext'
     keyword = 'text'
 
     text = VariablesField('WFTextActionText', help='Output of this action')
