@@ -3,7 +3,7 @@ from shortcuts.actions.base import BaseAction, Field, WFVariableField
 
 class SetVariableAction(BaseAction):
     '''Set variable: saves input to a variable with a name=`name`'''
-    type = 'is.workflow.actions.setvariable'
+    itype = 'is.workflow.actions.setvariable'
     keyword = 'set_variable'
 
     name = Field('WFVariableName')
@@ -11,7 +11,7 @@ class SetVariableAction(BaseAction):
 
 class GetVariableAction(BaseAction):
     '''Get variable: returns variable with name=`name` in the output'''
-    type = 'is.workflow.actions.getvariable'
+    itype = 'is.workflow.actions.getvariable'
     keyword = 'get_variable'
 
     name = WFVariableField('WFVariable')
